exec

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 4, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunWithOutput

func RunWithOutput(name string, arg ...string) error

RunWithOutput executes a command and shows output (deprecated - use RunQuiet instead)

Types

type RunResult

type RunResult struct {
	Success bool
	LogFile string
	Error   error
}

RunResult contains the result of running a command

func Run

func Run(name string, arg ...string) RunResult

Run executes a command and captures output On success: returns success with no log file On failure: writes output to log file and returns path

func RunQuiet

func RunQuiet(name string, arg ...string) RunResult

RunQuiet executes a command silently, logging to file on error

Jump to