Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Homebrew ¶
type Homebrew struct{}
Homebrew implements the Manager interface for macOS Homebrew
func (*Homebrew) IsInstalled ¶
IsInstalled checks if a package is installed via Homebrew
type Manager ¶
type Manager interface {
Install(packages ...string) error
IsInstalled(pkg string) bool
Name() string
}
Manager defines the interface for package managers
func NewManager ¶
NewManager creates a package manager based on the OS
type Noop ¶
type Noop struct{}
Noop is a no-op package manager for unsupported platforms
func (*Noop) IsInstalled ¶
Click to show internal directories.
Click to hide internal directories.